
#ifndef _C12_fi581_
#define _C12_fi581_

#ifdef __cplusplus
extern "C" {
#endif

extern EIF_BOOLEAN F584_3155(EIF_REFERENCE);
extern void EIF_Minit581(void);
extern EIF_INTEGER_32 F686_3633(EIF_REFERENCE);

#ifdef __cplusplus
}
#endif

#endif
